@@ -14,12 +14,12 @@ use RPi::WiringPi::Interrupt;
 use RPi::WiringPi::LCD;
 use RPi::WiringPi::Pin;
 
-our $VERSION = '2.36.5';
+our $VERSION = '2.36.6';
 
 my $fatal_exit = 1;
 
 BEGIN {
-    sub error {
+    sub _error {
         my $err = shift;
         print "\ndie() caught... ".  __PACKAGE__ ." is cleaning up\n",
         RPi::WiringPi::Util::cleanup();
@@ -28,8 +28,8 @@ BEGIN {
         exit if $fatal_exit;
     }
 
-    $SIG{__DIE__} = \&error;
-    $SIG{INT} = \&error;
+    $SIG{__DIE__} = \&_error;
+    $SIG{INT} = \&_error;
 };
 
 # core
@@ -190,7 +190,7 @@ various items
     my $buf = [0x01, 0x02];
     my $len = scalar @$buf;
 
-    $spi->rw($buf, $len);
+    my @read_bytes = $spi->rw($buf, $len);
 
     #
     # digital potentiometer
@@ -424,6 +424,8 @@ Returns a L<RPi::WiringPi::BMP180> object, which allows you to return the
 current temperature in farenheit or celcius, along with the ability to retrieve
 the barometric pressure in kPa.
 
+=head1 INTERNAL PUBLIC METHODS
+
 =head1 RUNNING TESTS
 
 Please see L<RUNNING TESTS|RPi::WiringPi::FAQ/RUNNING-TESTS> in the
